@@ -1,6 +1,6 @@
 //
 // This file is part of Gambit
-// Copyright (c) 1994-2010, The Gambit Project (http://www.gambit-project.org)
+// Copyright (c) 1994-2014, The Gambit Project (http://www.gambit-project.org)
 //
 // FILE: src/gui/efgpanel.cc
 // Main viewing panel for extensive forms
@@ -28,8 +28,11 @@
 #include <wx/image.h>         // for creating drag-and-drop cursor
 #include <wx/print.h>         // for printing support
 #include <wx/colordlg.h>      // for picking player colors
-
-#include "dcsvg.h"         // for SVG output
+#if wxCHECK_VERSION(2, 9, 0)
+#include <wx/dcsvg.h>         // for SVG output
+#else
+#include "dcsvg.h"
+#endif  /* wxCHECK_VERSION */
 
 #include "efgpanel.h"
 #include "efgdisplay.h"  // FIXME: communicate with tree window via events.
@@ -159,8 +162,9 @@ void gbtBehavDominanceToolbar::OnLastLevel(wxCommandEvent &)
 
 void gbtBehavDominanceToolbar::OnShowReachable(wxCommandEvent &)
 {
-  m_doc->GetStyle().SetRootReachable(!m_doc->GetStyle().RootReachable());
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_NONE);
+  gbtStyle style = m_doc->GetStyle();
+  style.SetRootReachable(!style.RootReachable());
+  m_doc->SetStyle(style);
 }
 
 void gbtBehavDominanceToolbar::OnUpdate(void)
@@ -333,6 +337,7 @@ gbtTreePlayerPanel::gbtTreePlayerPanel(wxWindow *p_parent,
   topSizer->SetSizeHints(this);
   topSizer->Fit(this);
   Layout();
+  OnUpdate();
 }
 
 void gbtTreePlayerPanel::OnUpdate(void)
@@ -431,8 +436,9 @@ void gbtTreePlayerPanel::OnSetColor(wxCommandEvent &)
 
   if (dialog.ShowModal() == wxID_OK) {
     wxColour color = dialog.GetColourData().GetColour();
-    m_doc->GetStyle().SetPlayerColor(m_player, color);
-    m_doc->UpdateViews(GBT_DOC_MODIFIED_VIEWS);
+    gbtStyle style = m_doc->GetStyle();
+    style.SetPlayerColor(m_player, color);
+    m_doc->SetStyle(style);
   }
 }
 
@@ -444,16 +450,16 @@ void gbtTreePlayerPanel::OnEditPlayerLabel(wxCommandEvent &)
 
 void gbtTreePlayerPanel::OnAcceptPlayerLabel(wxCommandEvent &)
 {
-  m_doc->GetGame()->GetPlayer(m_player)->SetLabel((const char *) m_playerLabel->GetValue().mb_str());
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_LABELS);
+  m_doc->DoSetPlayerLabel(m_doc->GetGame()->GetPlayer(m_player),
+			  m_playerLabel->GetValue());
 }
 
 void gbtTreePlayerPanel::PostPendingChanges(void)
 {
   if (m_playerLabel->IsEditing()) {
     m_playerLabel->EndEdit(true);
-    m_doc->GetGame()->GetPlayer(m_player)->SetLabel((const char *) m_playerLabel->GetValue().mb_str());
-    m_doc->UpdateViews(GBT_DOC_MODIFIED_LABELS);
+    m_doc->DoSetPlayerLabel(m_doc->GetGame()->GetPlayer(m_player), 
+			    m_playerLabel->GetValue());
   }
 }
 
@@ -562,8 +568,9 @@ void gbtTreeChancePanel::OnSetColor(wxCommandEvent &)
 
   if (dialog.ShowModal() == wxID_OK) {
     wxColour color = dialog.GetColourData().GetColour();
-    m_doc->GetStyle().SetChanceColor(color);
-    m_doc->UpdateViews(GBT_DOC_MODIFIED_VIEWS);
+    gbtStyle style = m_doc->GetStyle();
+    style.SetChanceColor(color);
+    m_doc->SetStyle(style);
   }
 }
 
@@ -589,7 +596,7 @@ public:
 
 gbtTreePlayerToolbar::gbtTreePlayerToolbar(wxWindow *p_parent, 
 					   gbtGameDocument *p_doc)
-  : wxPanel(p_parent, -1, wxDefaultPosition, wxSize(110, -1)), 
+  : wxPanel(p_parent, -1, wxDefaultPosition, wxSize(210, -1)), 
     gbtGameView(p_doc)
 { 
   wxBoxSizer *topSizer = new wxBoxSizer(wxVERTICAL);
@@ -617,7 +624,7 @@ void gbtTreePlayerToolbar::OnUpdate(void)
 
   while (m_playerPanels.Length() > m_doc->NumPlayers()) {
     gbtTreePlayerPanel *panel = m_playerPanels.Remove(m_playerPanels.Length());
-    GetSizer()->Remove(panel);
+    GetSizer()->Detach(panel);
     panel->Destroy();
   }
   
