@@ -1,6 +1,6 @@
 //
 // This file is part of Gambit
-// Copyright (c) 1994-2010, The Gambit Project (http://www.gambit-project.org)
+// Copyright (c) 1994-2014, The Gambit Project (http://www.gambit-project.org)
 //
 // FILE: src/gui/nfgtable.cc
 // Implementation of strategic game matrix display/editor
@@ -26,7 +26,11 @@
 #endif  // WX_PRECOMP
 #include <wx/dnd.h>      // for drag-and-drop support
 #include <wx/print.h>    // for printing support
-#include "dcsvg.h"         // for SVG output
+#if wxCHECK_VERSION(2, 9, 0)
+#include <wx/dcsvg.h>    // for SVG output
+#else
+#include "dcsvg.h"
+#endif  /* wxCHECK_VERSION */
 
 #include "wx/sheet/sheet.h"
 
@@ -35,6 +39,7 @@
 #include "gamedoc.h"
 #include "nfgpanel.h"
 #include "nfgtable.h"
+#include "dlexcept.h"
 
 //=========================================================================
 //                       class gbtTableWidgetBase
@@ -210,14 +215,13 @@ void gbtRowPlayerWidget::OnCellRightClick(wxSheetEvent &p_event)
     return;
   }
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
   wxSheetCoords coords = p_event.GetCoords();
 
   int player = m_table->GetRowPlayer(coords.GetCol() + 1);
   int strat = m_table->RowToStrategy(coords.GetCol() + 1, coords.GetRow());
 
-  support.GetStrategy(player, strat)->DeleteStrategy();
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_GAME);
+  m_doc->DoDeleteStrategy(support.GetStrategy(player, strat));
 }
 
 wxString gbtRowPlayerWidget::GetCellValue(const wxSheetCoords &p_coords)
@@ -226,7 +230,7 @@ wxString gbtRowPlayerWidget::GetCellValue(const wxSheetCoords &p_coords)
 
   if (m_table->NumRowPlayers() == 0) return wxT("Payoffs");
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
   int player = m_table->GetRowPlayer(p_coords.GetCol() + 1);
   int strat = m_table->RowToStrategy(p_coords.GetCol() + 1, p_coords.GetRow());
@@ -238,13 +242,12 @@ wxString gbtRowPlayerWidget::GetCellValue(const wxSheetCoords &p_coords)
 void gbtRowPlayerWidget::SetCellValue(const wxSheetCoords &p_coords,
 				      const wxString &p_value)
 {
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
   int player = m_table->GetRowPlayer(p_coords.GetCol() + 1);
   int strat = m_table->RowToStrategy(p_coords.GetCol() + 1, p_coords.GetRow());
 
-  support.GetStrategy(player, strat)->SetLabel((const char *) p_value.mb_str());
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_LABELS);
+  m_doc->DoSetStrategyLabel(support.GetStrategy(player, strat), p_value);
 }
 
 wxSheetCellAttr gbtRowPlayerWidget::GetAttr(const wxSheetCoords &p_coords,
@@ -273,7 +276,7 @@ void gbtRowPlayerWidget::DrawCell(wxDC &p_dc, const wxSheetCoords &p_coords)
   if (!m_table->ShowDominance() || IsLabelCell(p_coords) ||
       m_table->NumRowPlayers() == 0)  return;
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
   int player = m_table->GetRowPlayer(p_coords.GetCol() + 1);
   int strat = m_table->RowToStrategy(p_coords.GetCol() + 1, p_coords.GetRow());
   Gambit::GameStrategy strategy = support.GetStrategy(player, strat);
@@ -422,14 +425,13 @@ void gbtColPlayerWidget::OnCellRightClick(wxSheetEvent &p_event)
     return;
   }
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
   wxSheetCoords coords = p_event.GetCoords();
 
   int player = m_table->GetColPlayer(coords.GetRow() + 1);
   int strat = m_table->RowToStrategy(coords.GetRow() + 1, coords.GetCol());
 
-  support.GetStrategy(player, strat)->DeleteStrategy();
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_GAME);
+  m_doc->DoDeleteStrategy(support.GetStrategy(player, strat));
 }
 
 void gbtColPlayerWidget::OnUpdate(void)
@@ -465,7 +467,7 @@ wxString gbtColPlayerWidget::GetCellValue(const wxSheetCoords &p_coords)
 
   if (m_table->NumColPlayers() == 0)  return wxT("Payoffs");
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
   int player = m_table->GetColPlayer(p_coords.GetRow() + 1);
   int strat = m_table->ColToStrategy(p_coords.GetRow() + 1, p_coords.GetCol());
@@ -477,13 +479,12 @@ wxString gbtColPlayerWidget::GetCellValue(const wxSheetCoords &p_coords)
 void gbtColPlayerWidget::SetCellValue(const wxSheetCoords &p_coords,
 				      const wxString &p_value)
 {
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
   int player = m_table->GetColPlayer(p_coords.GetRow() + 1);
   int strat = m_table->ColToStrategy(p_coords.GetRow() + 1, p_coords.GetCol());
 
-  support.GetStrategy(player, strat)->SetLabel((const char *) p_value.mb_str());
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_LABELS);
+  m_doc->DoSetStrategyLabel(support.GetStrategy(player, strat), p_value);
 }
 
 wxSheetCellAttr gbtColPlayerWidget::GetAttr(const wxSheetCoords &p_coords,
@@ -512,7 +513,7 @@ void gbtColPlayerWidget::DrawCell(wxDC &p_dc, const wxSheetCoords &p_coords)
   if (!m_table->ShowDominance() || IsLabelCell(p_coords) ||
       m_table->NumColPlayers() == 0)  return;
 
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
   int player = m_table->GetColPlayer(p_coords.GetRow() + 1);
   int strat = m_table->ColToStrategy(p_coords.GetRow() + 1, p_coords.GetCol());
   Gambit::GameStrategy strategy = support.GetStrategy(player, strat);
@@ -656,28 +657,31 @@ wxString gbtPayoffsWidget::GetCellValue(const wxSheetCoords &p_coords)
 
   Gambit::PureStrategyProfile profile = m_table->CellToProfile(p_coords);
   int player = ColToPlayer(p_coords.GetCol());
-  return wxString(profile.GetPayoff<std::string>(player).c_str(), *wxConvCurrent);
+  return wxString(Gambit::lexical_cast<std::string>(profile->GetPayoff(player)).c_str(), *wxConvCurrent);
 }
 
 void gbtPayoffsWidget::SetCellValue(const wxSheetCoords &p_coords,
 				    const wxString &p_value)
 {
   Gambit::PureStrategyProfile profile = m_table->CellToProfile(p_coords);
-  Gambit::GameOutcome outcome = profile.GetOutcome();
+  Gambit::GameOutcome outcome = profile->GetOutcome();
   if (!outcome) {
-    outcome = m_doc->GetGame()->NewOutcome();
-    profile.SetOutcome(outcome);
+    m_doc->DoNewOutcome(profile);
+    profile = m_table->CellToProfile(p_coords);
+    outcome = profile->GetOutcome();
   }
   int player = ColToPlayer(p_coords.GetCol());
   try {
-    outcome->SetPayoff(player, (const char *) p_value.mb_str());
+    m_doc->DoSetPayoff(outcome, player, p_value);
   }
   catch (ValueException &) {
     // For the moment, we will just silently discard edits which 
     // give payoffs that are not valid numbers
     return;
   }
-  m_doc->UpdateViews(GBT_DOC_MODIFIED_PAYOFFS);
+  catch (std::exception &ex) {
+    gbtExceptionDialog(this, ex.what()).ShowModal();
+  }
 }
 
 wxSheetCellAttr gbtPayoffsWidget::GetAttr(const wxSheetCoords &p_coords,
@@ -735,11 +739,11 @@ void gbtPayoffsWidget::DrawCell(wxDC &p_dc, const wxSheetCoords &p_coords)
 
   Gambit::PureStrategyProfile profile = m_table->CellToProfile(p_coords);
   int player = ColToPlayer(p_coords.GetCol());
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
-  if (support.IsDominated(profile.GetStrategy(player), false)) {
+  if (support.IsDominated(profile->GetStrategy(player), false)) {
     wxRect rect = CellToRect(p_coords);
-    if (support.IsDominated(profile.GetStrategy(player), true)) {
+    if (support.IsDominated(profile->GetStrategy(player), true)) {
       p_dc.SetPen(wxPen(m_doc->GetStyle().GetPlayerColor(player),
 			2, wxSOLID));
     }
@@ -817,7 +821,7 @@ gbtTableWidget::gbtTableWidget(gbtNfgPanel *p_parent, wxWindowID p_id,
   m_rowSheet = new gbtRowPlayerWidget(this, p_doc);
   m_colSheet = new gbtColPlayerWidget(this, p_doc);
 
-  wxFlexGridSizer *topSizer = new wxFlexGridSizer(2, 2);
+  wxFlexGridSizer *topSizer = new wxFlexGridSizer(2, 2, 0, 0);
   topSizer->AddGrowableRow(1);
   topSizer->AddGrowableCol(1);
   topSizer->Add(new wxPanel(this, -1));
@@ -1043,32 +1047,20 @@ void gbtTableWidget::SetRowPlayer(int index, int pl)
 
 int gbtTableWidget::NumRowContingencies(void) const
 {
-  if (!m_doc->GetGame()->IsTree() || 
-      (m_doc->GetGame()->IsTree() && m_doc->GetGame()->HasComputedValues())) {
-    int ncont = 1;
-    const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
-    for (int i = 1; i <= NumRowPlayers(); 
-	 ncont *= support.NumStrategies(GetRowPlayer(i++)));
-    return ncont;
-  }
-  else {
-    return 0;
-  }
+  int ncont = 1;
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
+  for (int i = 1; i <= NumRowPlayers(); 
+       ncont *= support.NumStrategies(GetRowPlayer(i++)));
+  return ncont;
 }
 
 int gbtTableWidget::NumRowsSpanned(int index) const
 {
-  if (!m_doc->GetGame()->IsTree() || 
-      (m_doc->GetGame()->IsTree() && m_doc->GetGame()->HasComputedValues())) {
-    int ncont = 1;
-    const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
-    for (int i = index + 1; i <= NumRowPlayers(); 
-	 ncont *= support.NumStrategies(GetRowPlayer(i++)));
-    return ncont;
-  }
-  else {
-    return 1;
-  }
+  int ncont = 1;
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
+  for (int i = index + 1; i <= NumRowPlayers(); 
+       ncont *= support.NumStrategies(GetRowPlayer(i++)));
+  return ncont;
 }
 
 int gbtTableWidget::RowToStrategy(int player, int row) const
@@ -1098,32 +1090,20 @@ void gbtTableWidget::SetColPlayer(int index, int pl)
 
 int gbtTableWidget::NumColContingencies(void) const
 {
-  if (!m_doc->GetGame()->IsTree() || 
-      (m_doc->GetGame()->IsTree() && m_doc->GetGame()->HasComputedValues())) {
-    int ncont = 1;
-    const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
-    for (int i = 1; i <= NumColPlayers(); 
-	 ncont *= support.NumStrategies(GetColPlayer(i++)));
-    return ncont;
-  }
-  else {
-    return 0;
-  }
+  int ncont = 1;
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
+  for (int i = 1; i <= NumColPlayers(); 
+       ncont *= support.NumStrategies(GetColPlayer(i++)));
+  return ncont;
 }
 
 int gbtTableWidget::NumColsSpanned(int index) const
 {
-  if (!m_doc->GetGame()->IsTree() || 
-      (m_doc->GetGame()->IsTree() && m_doc->GetGame()->HasComputedValues())) {
-    int ncont = 1;
-    const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
-    for (int i = index + 1; i <= NumColPlayers(); 
-	 ncont *= support.NumStrategies(GetColPlayer(i++)));
-    return ncont;
-  }
-  else {
-    return 1;
-  }
+  int ncont = 1;
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
+  for (int i = index + 1; i <= NumColPlayers(); 
+       ncont *= support.NumStrategies(GetColPlayer(i++)));
+  return ncont;
 }
 
 int gbtTableWidget::ColToStrategy(int player, int col) const
@@ -1135,19 +1115,19 @@ int gbtTableWidget::ColToStrategy(int player, int col) const
 Gambit::PureStrategyProfile 
 gbtTableWidget::CellToProfile(const wxSheetCoords &p_coords) const
 {
-  const Gambit::StrategySupport &support = m_doc->GetNfgSupport();
+  const Gambit::StrategySupportProfile &support = m_doc->GetNfgSupport();
 
-  Gambit::PureStrategyProfile profile(m_doc->GetGame());
+  Gambit::PureStrategyProfile profile = m_doc->GetGame()->NewPureStrategyProfile();
   for (int i = 1; i <= NumRowPlayers(); i++) {
     int player = GetRowPlayer(i);
-    profile.SetStrategy(support.GetStrategy(player,
-					    RowToStrategy(i, p_coords.GetRow())));
+    profile->SetStrategy(support.GetStrategy(player,
+					     RowToStrategy(i, p_coords.GetRow())));
   }
 
   for (int i = 1; i <= NumColPlayers(); i++) {
     int player = GetColPlayer(i);
-    profile.SetStrategy(support.GetStrategy(player,
-					    ColToStrategy(i, p_coords.GetCol())));
+    profile->SetStrategy(support.GetStrategy(player,
+					     ColToStrategy(i, p_coords.GetCol())));
   }
 
   return profile;
