@@ -9,10 +9,6 @@
 // Licence:     wxWidgets licence
 ///////////////////////////////////////////////////////////////////////////////
 
-#if defined(__GNUG__) && !defined(NO_GCC_PRAGMA)
-    #pragma implementation "sheettbl.h"
-#endif
-
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
@@ -22,7 +18,7 @@
 
 #include "wx/sheet/sheettbl.h"
 #include "wx/sheet/sheet.h"
-#include <math.h>                 // used in GetDefaultColLabelValue
+#include <cmath>                 // used in GetDefaultColLabelValue
 
 #ifndef WX_PRECOMP
 #endif // WX_PRECOMP
@@ -796,7 +792,7 @@ wxString wxSheetTable::GetDefaultColLabelValue( int col ) const
  
     // new method using log function so you don't have to reverse the string
     wxCHECK_MSG(col >= 0, wxEmptyString, wxT("Invalid col"));
-    const size_t chars = size_t(log(col)/3.2580965380); // log_26(x) = log(x)/log(26.0)
+    const size_t chars = size_t(log((double) col)/3.2580965380); // log_26(x) = log(x)/log(26.0)
     wxString s(wxT('A'), chars+1);
     for ( size_t n = 0; n <= chars; n++ )
     {
