@@ -1078,10 +1078,10 @@ Game ReadGame(std::istream &p_file) throw (InvalidFileException)
       return game;
     }
     else if (parser.GetLastText() == "#AGG") {
-      return GameAggRep::ReadAggFile(p_file);
+      return GameAggRep::ReadAggFile(buffer);
     }
     else if (parser.GetLastText() == "#BAGG") {
-      return GameBagentRep::ReadBaggFile(p_file);
+      return GameBagentRep::ReadBaggFile(buffer);
     }
     else {
       throw InvalidFileException("Tokens 'EFG' or 'NFG' or '#AGG' or '#BAGG' expected at start of file");
