@@ -25,9 +25,9 @@ import nash
 import gte
 
 __version__ = gambit.lib.libgambit.__version__
+Rational = gambit.lib.libgambit.Rational
+Decimal = gambit.lib.libgambit.Decimal
 
 class Game(gambit.lib.libgambit.Game): pass
 
-    
-    
 
