@@ -29,8 +29,6 @@
 #include "complex.h"
 */
 
-inline double abs(double x) { return fabs(x); }
-
 /*************************************************************/
 /************** Implementation of class Pelview **************/
 /*************************************************************/
@@ -542,7 +540,7 @@ PelView::RealRoots(const Gambit::List<Gambit::Vector<gComplex> > &clist) const
 
     bool is_real = true;
     for (int j = 1; j <= Dmnsn(); j++)
-      if (abs(clist[i][j].ImaginaryPart()) > 0.0001) 
+      if (Gambit::abs(clist[i][j].ImaginaryPart()) > 0.0001) 
 	is_real = false;
 
     if (is_real) {
@@ -562,7 +560,7 @@ bool PelView::CheckSolutions(const Gen_node g) const
   Gen_node goo;
   goo = g->Genval.lval;
   while (goo!=0) { 
-    if (abs(goo->Genval.dval) > 0.01) 
+    if (Gambit::abs(goo->Genval.dval) > 0.01) 
       return 0;
 
     goo = goo->next;
